@@ -468,8 +468,26 @@ typedef struct WindowConditionMask
 	int placed_by_button_set_mask;
 } WindowConditionMask;
 
+typedef struct pl_penalty_struct
+{
+	float normal;
+	float ontop;
+	float icon;
+	float sticky;
+	float below;
+	float strut;
+} pl_penalty_struct;
+
+typedef struct pl_percent_penalty_struct
+{
+	int p99;
+	int p95;
+	int p85;
+	int p75;
+} pl_percent_penalty_struct;
+
 /* only style.c and add_window.c are allowed to access this struct! */
-typedef struct
+typedef struct style_flags
 {
 	common_flags_t common;
 	unsigned do_decorate_transient : 1;
@@ -501,8 +519,7 @@ typedef struct
 #define PLACE_TILECASCADE       0x5
 #define PLACE_CASCADE_B         0x6
 #define PLACE_MINOVERLAP        0x7
-#define PLACE_CENTER            0x8
-#define PLACE_UNDERMOUSE        0x9
+#define PLACE_POSITION          0x8
 #define PLACE_MASK              0xF
 	unsigned placement_mode : 4;
 	unsigned ewmh_placement_mode : 2; /* see ewmh.h */
@@ -514,16 +531,23 @@ typedef struct
 	unsigned do_save_under : 1;
 	unsigned do_start_iconic : 1;
 	unsigned do_start_lowered : 1;
+ 	unsigned do_start_shaded : 1;
+ 	unsigned start_shaded_dir : 3;
 	unsigned has_border_width : 1;
 	unsigned has_color_back : 1;
 	unsigned has_color_fore : 1;
 	unsigned has_color_back_hi : 1;
 	unsigned has_color_fore_hi : 1;
 	unsigned has_decor : 1;
+	unsigned has_edge_delay_ms_move : 1;
+	unsigned has_edge_delay_ms_resize : 1;
+	unsigned has_edge_resistance_move : 1;
+	unsigned has_edge_resistance_xinerama_move : 1;
 	unsigned has_handle_width : 1;
 	unsigned has_icon : 1;
 	unsigned has_icon_boxes : 1;
 	unsigned has_icon_size_limits : 1;
+	unsigned has_min_window_size : 1;
 	unsigned has_max_window_size : 1;
 	unsigned has_icon_background_padding : 1;
 	unsigned has_icon_background_relief : 1;
@@ -535,6 +559,8 @@ typedef struct
 	unsigned has_no_handles : 1;
 	unsigned has_no_title : 1;
 	unsigned has_ol_decor : 1;
+	unsigned has_snap_grid : 1;
+	unsigned has_snap_attraction : 1;
 #if 0
 	unsigned has_condition_mask : 1;
 #endif
@@ -562,13 +588,16 @@ typedef struct
 	unsigned use_start_on_page_for_transient : 1;
 	unsigned use_start_on_screen : 1;
 	unsigned manual_placement_honors_starts_on_page : 1;
+	unsigned um_placement_honors_starts_on_page : 1;
 	unsigned capture_honors_starts_on_page : 1;
 	unsigned recapture_honors_starts_on_page : 1;
 	unsigned has_placement_penalty : 1;
 	unsigned has_placement_percentage_penalty : 1;
+	unsigned has_placement_position_string : 1;
+	unsigned has_initial_map_command_string : 1;
 } style_flags;
 
-typedef struct
+typedef struct style_id_t
 {
 	char *name;
 	XID window_id;
@@ -579,6 +608,25 @@ typedef struct
 	} flags;
 } style_id_t;
 
+typedef struct snap_attraction_t
+{
+	/* attractiveness of window edges */
+	int proximity;
+	/* mode of snap attraction */
+	int mode;
+	/* mode flags to do bit manipulation */
+	enum
+	{
+		SNAP_NONE = 0x00,
+		SNAP_WINDOWS = 0x01,
+		SNAP_ICONS = 0x02,
+		SNAP_SAME = 0x04,
+		SNAP_SCREEN = 0x08,
+		SNAP_SCREEN_WINDOWS = 0x10,
+		SNAP_SCREEN_ICONS = 0x20,
+		SNAP_SCREEN_ALL = 0x40,
+	} types;
+} snap_attraction_t;
 
 /* only style.c and add_window.c are allowed to access this struct! */
 typedef struct window_style
@@ -628,13 +676,27 @@ typedef struct window_style
 	int start_page_x;
 	int start_page_y;
 	int start_screen;
+	int min_window_width;
+	int min_window_height;
 	int max_window_width;
 	int max_window_height;
 	int shade_anim_steps;
+#if 1 /*!!!*/
+	snap_attraction_t snap_attraction;
+	/* snap grid size */
+	int snap_grid_x;
+	int snap_grid_y;
+	int edge_delay_ms_move;
+	int edge_delay_ms_resize;
+	int edge_resistance_move;
+	int edge_resistance_xinerama_move;
+#endif
 	icon_boxes *icon_boxes;
 	float norm_placement_penalty;
-	float placement_penalty[6];
-	int placement_percentage_penalty[4];
+	pl_penalty_struct pl_penalty;
+	pl_percent_penalty_struct pl_percent_penalty;
+	char *pl_position_string;
+	char *initial_map_command_string;
 	style_flags flags;
 	style_flags flag_default;
 	style_flags flag_mask;
@@ -843,10 +905,22 @@ typedef struct FvwmWindow
 	char icon_background_relief;
 	char icon_title_relief;
 
+	int min_window_width;
+	int min_window_height;
 	int max_window_width;
 	int max_window_height;
 	int shade_anim_steps;
 	unsigned char grabbed_buttons;
+#if 1 /*!!!*/
+	snap_attraction_t snap_attraction;
+	/* snap grid size */
+	int snap_grid_x;
+	int snap_grid_y;
+	int edge_delay_ms_move;
+	int edge_delay_ms_resize;
+	int edge_resistance_move;
+	int edge_resistance_xinerama_move;
+#endif
 
 #define FM_NO_INPUT        0
 #define FM_PASSIVE         1
@@ -854,8 +928,8 @@ typedef struct FvwmWindow
 #define FM_GLOBALLY_ACTIVE 3
 	unsigned char focus_model;
 
-	float placement_penalty[6];
-	int placement_percentage_penalty[4];
+	pl_penalty_struct pl_penalty;
+	pl_percent_penalty_struct pl_percent_penalty;
 
 	unsigned char placed_by_button;
 
@@ -904,5 +978,6 @@ typedef struct FvwmWindow
 /* ---------------------------- interface functions ------------------------ */
 
 void SetMWM_INFO(Window window);
+void fvmm_deinstall_signals(void);
 
 #endif /* FVWM_H */
