@@ -59,6 +59,11 @@
 #include "libs/FShape.h"
 #include "libs/FRender.h"
 #include "libs/FRenderInit.h"
+#include "libs/Graphics.h"
+#include "libs/Parse.h"
+#include "libs/Strings.h"
+#include "libs/System.h"
+#include "libs/XError.h"
 
 #include "libs/Colorset.h"
 #include "fvwm/fvwm.h"
@@ -285,11 +290,7 @@ int main(int argc, char **argv)
 	      XDisplayName(display_name));
       exit (1);
     }
-  PictureInitCMap(dpy);
-  FScreenInit(dpy);
-  AllocColorset(0);
-  FShapeInit(dpy);
-  FRenderInit(dpy);
+  flib_init_graphics(dpy);
 
   x_fd = XConnectionNumber(dpy);
 
@@ -1382,7 +1383,6 @@ void CreateWindow(void)
     /* hack to prevent mapping on wrong screen with StartsOnScreen */
     FScreenMangleScreenIntoUSPosHints(FSCREEN_XYPOS, &mysizehints);
   }
-/*!!!*/fprintf(stderr, "pos %d %d, grav %d\n", wx, wy, gravity);
 
   mysizehints.win_gravity = gravity;
 
@@ -1998,7 +1998,6 @@ void ParseOptions(void)
 	  xneg = 1;
 	if (flags & YNegative)
 	  yneg = 1;
-/*!!!*/fprintf(stderr, "geom: size %d %d, pos %d %d, neg %d %d\n", num_columns, num_rows, geom_x, geom_y, xneg, yneg);
       }
       else if (strncasecmp(tline,CatString3(
 			     "*", MyName, "MaxIconSize"),Clength+12)==0)
